@@ -25,7 +25,7 @@ class Slider(XBlock):
                                       max=self.max_value,
                                       val=self.value)
         frag = Fragment(html)
-        frag.add_css(u"input[type=range] { width=100px; }")
+        frag.add_css("input[type=range] { width=100px; }")
         frag.add_javascript(SLIDER_JS)
         frag.initialize_js('Slider')
 
@@ -38,11 +38,11 @@ class Slider(XBlock):
         return Response()
 
 
-SLIDER_TEMPLATE = u"""
+SLIDER_TEMPLATE = """
 <input type="range" min="{min}" max="{max}" value="{val}"/> <span> {val} </span>
 """
 
-SLIDER_JS = u"""
+SLIDER_JS = """
 function Slider(runtime, element) {
   if (!(this instanceof Slider)) {
     return new Slider(runtime, element);
